@@ -25,6 +25,8 @@ class StopWatch(object):
     timer_elapsed = {}
     # records a status
     timer_status = {}
+    # records a dt
+    timer_sum = {}
 
     @classmethod
     def keys(cls):
@@ -56,6 +58,8 @@ class StopWatch(object):
         """
         if cls.debug:
             print("Timer", name, "started ...")
+        if name not in cls.timer_sum:
+            cls.timer_sum[name] = 0.0
         cls.timer_start[name] = time.time()
         cls.timer_end[name] = None
         cls.timer_status[name] = None
@@ -69,13 +73,17 @@ class StopWatch(object):
         :type name: string
         """
         cls.timer_end[name] = time.time()
+        #if cumulate:
+        #    cls.timer_end[name] = cls.timer_end[name] + cls.timer_last[name]
+        cls.timer_sum[name] = cls.timer_sum[name]  +  cls.timer_end[name] - cls.timer_start[name]
+
         if cls.debug:
             print("Timer", name, "stopped ...")
 
     @classmethod
     def get_status(cls, name):
         """
-        stops the timer with a given name.
+        sets the status of the timer with a given name.
 
         :param name: the name of the timer
         :type name: string
@@ -83,7 +91,7 @@ class StopWatch(object):
         return cls.timer_status[name]
 
     @classmethod
-    def get(cls, name, digits=None):
+    def get(cls, name, digits=4):
         """
         returns the time of the timer.
 
@@ -104,6 +112,27 @@ class StopWatch(object):
         else:
             return "undefined"
 
+    @classmethod
+    def sum(cls, name, digits=4):
+        """
+        returns the sum of the timer if used multiple times
+
+        :param name: the name of the timer
+        :type name: string
+        :rtype: the elapsed time
+        """
+        if name in cls.timer_end:
+            try:
+                diff = cls.timer_sum[name]
+                if round is not None:
+                    return round(diff, digits)
+                else:
+                    return diff
+            except:
+                return None
+        else:
+            return "undefined"
+
     @classmethod
     def clear(cls):
         """
@@ -111,6 +140,9 @@ class StopWatch(object):
         """
         cls.timer_start.clear()
         cls.timer_end.clear()
+        cls.timer_sum.clear()
+        cls.timer_status.clear()
+        cls.timer_elapsed.clear()
 
     @classmethod
     def print(cls, *args):
@@ -144,7 +176,8 @@ class StopWatch(object):
                   sysinfo=True,
                   csv=True,
                   prefix="# csv",
-                  tag=None):
+                  tag=None,
+                  sum=True):
         """
         prints out all timers in a convenient benchmark table
         :return:
@@ -181,6 +214,7 @@ class StopWatch(object):
                                            time.gmtime(
                                                StopWatch.timer_start[timer])),
                     'time': StopWatch.get(timer, digits=3),
+                    'sum': StopWatch.sum(timer, digits=3),
                     'status': StopWatch.get_status(timer),
                     'timer': timer,
                     'tag': tag or ''
@@ -211,6 +245,7 @@ class StopWatch(object):
                 "timer",
                 "status",
                 "time",
+                "sum",
                 "start",
                 "tag",
                 "uname.node",
@@ -223,6 +258,7 @@ class StopWatch(object):
                 "Name",
                 "Status",
                 "Time",
+                "Sum",
                 "Start",
                 "tag",
                 "Node",
